# winaccent
A simple module for getting Windows' accent color. With this module you can get both light and dark mode accent colors.

# Installation
Run this command in your terminal:

```
pip install winaccent
```

# Documentation

| Variable | Info |
|----------|------|
| winaccent.accent_light | Returns the light mode accent color
| winaccent.accent_dark | Returns the dark mode accent color
| winaccent.accent_normal | Returns the normal accent color
| winaccent.accent_auto | Returns the light/dark accent color depending on the system theme

# Output
Here is the output for the default (blue) accent color on Windows 11:

| Variable | Color | Preview |
|----------|:-------:|:-------:|
| winaccent.accent_light | #0067C0 | <img src="https://github.com/Valer100/winaccent/blob/main/assets/colors/accent_light.png?raw=true"> |
| winaccent.accent_dark | #4CC2FF | <img src="https://github.com/Valer100/winaccent/blob/main/assets/colors/accent_dark.png?raw=true"> |
| winaccent.accent_normal | #0078D4 | <img src="https://github.com/Valer100/winaccent/blob/main/assets/colors/accent_normal.png?raw=true"> |

Here is the output for a custom accent color (green):


| Variable | Color | Preview |
|----------|:-------:|:-------:|
| winaccent.accent_light | #007300 | <img src="https://github.com/Valer100/winaccent/blob/main/assets/colors/accent_light_green.png?raw=true"> |
| winaccent.accent_dark | #3FFF24 | <img src="https://github.com/Valer100/winaccent/blob/main/assets/colors/accent_dark_green.png?raw=true"> |
| winaccent.accent_normal | #008B00 | <img src="https://github.com/Valer100/winaccent/blob/main/assets/colors/accent_normal_green.png?raw=true"> |